import request from '@/utils/request'

/**
 * 新增客户
 * @param customerName 客户名
 * @param customerEmail 客户邮箱
 * @param customerContact 客户联系人
 * @param customerPhone 客户电话
 * @param customerAddress 客户地址
 * @param status 状态
 * @param startTime 开始时间
 * @param endTim 结束时间
 */
export function addCustomer({ userName, nickName, password, roleId }) {
  return request({
    url: '/system/user/add',
    method: 'POST',
    data: { userName, nickName, password, roleId }
  })
}

/**
 * 修改客户
 * @param customerId 客户ID
 * @param customerName 客户名称
 * @param customerEmail 客户邮箱
 * @param customerContact 客户联系人
 * @param customerPhone 客户联系电话
 * @param customerAddress 客户地址
 * @param status 状态
 * @param contractTime 合同时间
 */
export function editCustomer({ userId, nickName, roleId  }) {
  return request({
    url: '/system/user/update_user',
    method: 'POST',
    data: { userId, nickName, roleId  }
  })
}

/**
 * 获取客户列表
 * @param current 当前页
 * @param size 每页记录数
 * @param customerName 客户名称
 * @param status 客户状态
 * @param startTime
 * @param endTime
 * @returns {Promise<void> | * | AxiosPromise<any> | ClientHttp2Stream | http.ClientRequest}
 */
export function listCustomer({userId, userName, nickName, roleId }) {
  return request({
    url: '/system/user/search',
    method: 'POST',
    data: {userId, userName, nickName, roleId }
  })
}

/**
 * 获取客户
 * @param customerId 客户ID
 */
export function getCustomer(customerId) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'GET'
  })
}

/**
 * 删除客户
 * @param customerId 客户ID
 */
export function deleteCustomer(customerId) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'DELETE'
  })
}
export function getAu(userId) {
  return request({
    url: '/system/function/user/list',
    method: 'POST',
    data: { userId}
  })
}
export function editStatus(userId, status) {
  return request({
    url: '/system/user/update_status' ,
    method: 'POST',
    data: { userId, status }
  })
}

export function editCheckList(userId, funCode) {
  return request({
    url: '/system/function/config' ,
    method: 'POST',
    data: { userId, funCode }
  })
}

export function resetPassword(userId,password,rePassword) {
  return request({
    url: '/system/user/update_password',
    method: 'POST',
    data: { userId,password,rePassword}
  })
}

export function getRz(userId) {
  return request({
    url: '/system/user/google/auth/bind',
    method: 'POST',
    data: { userId}
  })
}

export function getRzImg(qrFile) {
  return request({
    url: '/system/user/google/auth/get_qr_file',
    method: 'POST',
    data: { qrFile},
    responseType: 'blob'
  })
}
export function handleCancelRz(userId) {
  return request({
    url: '/system/user/google/auth/unbind',
    method: 'POST',
    data: { userId},
  })
}