import request from '@/utils/request'

/**
 * 新增客户
 * @param customerName 客户名
 * @param customerEmail 客户邮箱
 * @param customerContact 客户联系人
 * @param customerPhone 客户电话
 * @param customerAddress 客户地址
 * @param status 状态
 * @param startTime 开始时间
 * @param endTim 结束时间
 */
export function addCustomer({
  mediaCode,customerId, customerName,contact, contactPhone,contactEmail,payMethod,contractStartTime	,contractEndTime,role
}) {
  return request({
    url: '/user/yun_jing/customer/add',
    method: 'POST',
    data: {
      mediaCode,customerId, customerName,contact, contactPhone,contactEmail,payMethod,contractStartTime	,contractEndTime,role
    }
  })
}
export function getCustomerList() {
  return request({
      method: 'POST',
      url: '/system/customer/select',
  })
}
/**
 * 修改客户
 * @param customerId 客户ID
 * @param customerName 客户名称
 * @param customerEmail 客户邮箱
 * @param customerContact 客户联系人
 * @param customerPhone 客户联系电话
 * @param customerAddress 客户地址
 * @param status 状态
 * @param contractTime 合同时间
 */
export function editCustomer({ id,mediaCode,customerId, customerName,contact, contactPhone,contactEmail,payMethod,contractStartTime	,contractEndTime,role }) {
  return request({
    url: '/user/yun_jing/customer/edit',
    method: 'POST',
    data: {
      id,mediaCode,customerId, customerName,contact, contactPhone,contactEmail,payMethod,contractStartTime	,contractEndTime,role
    }
  })
}

/**
 * 获取客户列表
 * @param current 当前页
 * @param size 每页记录数
 * @param customerName 客户名称
 * @param status 客户状态
 * @param startTime
 * @param endTime
 * @returns {Promise<void> | * | AxiosPromise<any> | ClientHttp2Stream | http.ClientRequest}
 */
export function listCustomer({ current,size,mediaCode, name, status, startTime, endTime }) {
  return request({
    url: '/user/yun_jing/customer/search',
    method: 'POST',
    data: { current,size,mediaCode, name, status, startTime, endTime }
  })
}

/**
 * 获取客户
 * @param customerId 客户ID
 */
export function getCustomer(customerId) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'GET'
  })
}

/**
 * 删除客户
 * @param customerId 客户ID
 */
export function deleteCustomer(customerId) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'DELETE'
  })
}

export function editStatus(customerId, status) {
  return request({
    url: '/system/customer/' + customerId + '/' + status,
    method: 'PUT'
  })
}

export function resetPassword(customerId) {
  return request({
    url: `/system/customer/${customerId}/password/reset`,
    method: 'POST'
  })
}
