import request from '@/utils/request'

// 查询用户列表
export function listUser(query) {
  return request({
    url: '/system/user/list',
    method: 'get',
    params: query
  })
}

// 查询用户详细
export function getUser(userId) {
  return request({
    url: '/system/user/' + userId,
    method: 'get'
  })
}

// 新增用户
export function addUser(data) {
  return request({
    url: '/system/user',
    method: 'post',
    data: data
  })
}

// 修改用户
export function updateUser(data) {
  return request({
    url: '/system/user',
    method: 'put',
    data: data
  })
}

// 删除用户
export function delUser(userId) {
  return request({
    url: '/system/user/' + userId,
    method: 'delete'
  })
}

// 用户密码重置
export function resetUserPwd(userId, password) {
  const data = {
    userId,
    password
  }
  return request({
    url: '/system/user/resetPwd',
    method: 'put',
    data: data
  })
}

// 用户状态修改
export function changeUserStatus(userId, status) {
  const data = {
    userId,
    status
  }
  return request({
    url: '/system/user/changeStatus',
    method: 'put',
    data: data
  })
}

// 查询用户个人信息
export function getUserProfile() {
  return request({
    url: '/system/user/profile',
    method: 'get'
  })
}

// 修改用户个人信息
export function updateUserProfile(data) {
  return request({
    url: '/system/user/profile',
    method: 'put',
    data: data
  })
}

// 用户密码重置
export function updateUserPwd(oldPassword, newPassword) {
  const data = {
    oldPassword: oldPassword,
    newPassword: newPassword
  }
  return request({
    url: '/system/user/password',
    method: 'PUT',
    data: data
  })
}

// 用户头像上传
export function uploadAvatar(data) {
  return request({
    url: '/system/user/profile/avatar',
    method: 'post',
    data: data
  })
}

// 收数服务白名单新增
export function shoushuWhiteAdd(data) {
  return request({
    url: '/system/shoushu/white/add',
    method: 'post',
    data: data
  })
}

// 收数服务白名单修改
export function shoushuWhiteEdit(data) {
  return request({
    url: '/system/shoushu/white/edit',
    method: 'post',
    data: data
  })
}

// 收数服务白名单修改状态
export function shoushuWhiteEditStatus(data) {
  return request({
    url: '/system/shoushu/white/edit/status',
    method: 'post',
    data: data
  })
}

// 收数服务白名单查询
export function shoushuWhiteSearch(data) {
  return request({
    url: '/system/shoushu/white/search',
    method: 'post',
    data: data
  })
}

// 查询没有配置的下拉
export function shoushuWhiteCustomerList(data) {
  return request({
    url: '/system/shoushu/white/customer/list',
    method: 'post',
    data: data
  })
}

// 查询单个配置
export function shoushuWhiteGet(data) {
  return request({
    url: '/system/shoushu/white/get',
    method: 'post',
    data: data
  })
}
