import Vue from 'vue'
import Router from 'vue-router'
import { getRouters, getAu } from '@/api/menu'
Vue.use(Router)

/* Layout */
import Layout from '@/layout'

import store from '@/store'
/**
 * Note: 路由配置项
 *
 * hidden: true                   // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true               // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect           // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'             // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * meta : {
    roles: ['admin','editor']    // 设置该路由进入的权限，支持多个权限叠加
    title: 'title'               // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'             // 设置该路由的图标，对应路径src/icons/svg
    breadcrumb: false            // 如果设置为false，则不会在breadcrumb面包屑中显示
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    name: '',
    children: [
      {
        path: '/redirect/:path*',
        component: () => import('@/views/redirect')
      }
    ]
  },
  {
    path: '/login',
    name: '',
    component: () => import('@/views/login'),
    hidden: true
  },
  {
    path: '/resetpassword',
    component: () => import('@/views/resetpassword'),
    hidden: true
  },
  {
    path: '/404',
    name: '',
    component: Layout,
    children: [{
      path: '/404',
      component: () => import('@/views/error/404')
    }],

  },
  {
    path: '/401',
    name: '',
    component: () => import('@/views/error/401'),
    hidden: true
  },
  {
    path: '',
    component: Layout,
    name: '搜索文档',
    redirect: 'index',
    children: [
      {
        path: 'index',
        component: () => import('@/views/index'),
        name: '搜索文档',
        meta: { title: '搜索文档', icon: 'search-new', noCache: true, affix: true }
      }
    ]
  },
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    name: '',
    children: [
      {
        path: 'profile',
        component: () => import('@/views/system/user/profile/index'),
        name: '个人中心',
        meta: { title: '个人中心', icon: 'user' }
      }
    ]
  },
  {
    path: '/dict',
    component: Layout,
    hidden: true,
    name: '',
    children: [
      {
        path: 'type/data/:dictId(\\d+)',
        component: () => import('@/views/system/dict/data'),
        name: '字典数据',
        meta: { title: '字典数据', icon: '' }
      }
    ]
  },
  {
    component: Layout,
    name: '文档管理',
    meta: {
      icon: 'white',
      title: '文档管理'
    },
    path: '/documentManagement',
    children: [
      {
        component: () => import('@/views/dataList/dashboard/index'),
        meta: {
          icon: '',
          title: '搜索文档详情'
        },
        name: 'tailAfter',
        path: 'tailAfter',
        hidden: true
      },
      {
        component: () => import('@/views/system/customer/index'),
        meta: {
          icon: '',
          title: '跟踪文档'
        },
        name: 'taskList',
        path: 'taskList',
        props: {
          default: false
        }
      },
      {
        component: () => import('@/views/taskList/index'),
        meta: {
          icon: '',
          title: '跟踪文档详情'
        },
        name: 'taskListIndex',
        path: 'taskListIndex',
        props: {
          default: false
        },
        hidden: true
      },
      // {
      //   component: () => import('@/views/dataList/putIn/index'),
      //   meta: {
      //     icon: '',
      //     title: '客户投放List'
      //   },
      //   name: 'PutIn',
      //   path: 'PutIn'
      // }
    ]
  },
  // {
  //   path: '/taskList',
  //   component: Layout,
  //   name: '跟踪文档详情',
  //   meta: {
  //     icon: 'system',
  //     title: '跟踪文档详情'
  //   },
  //   children: [
  //     {
  //       component: () => import('@/views/taskList/index'),
  //       meta: {
  //         icon: '',
  //         title: '跟踪文档详情'
  //       },
  //       name: 'taskListIndex',
  //       path: 'taskListIndex',
  //       props: {
  //         default: false
  //       }
  //     },
  //   ]
  // },
  // {
  //   component: Layout,
  //   meta: {
  //     icon: 'peoples',
  //     title: '人群市场'
  //   },
  //   name: '人群市场',
  //   path: '/audience',
  //   children: [
  //     {
  //       component: () => import('@/views/audience/customer/index'),
  //       meta: {
  //         icon: '',
  //         title: '人群客户管理'
  //       },
  //       name: '人群客户管理',
  //       path: 'customer'
  //     },
  //     {
  //       name: '人群包管理',
  //       path: 'package',
  //       meta: {
  //         icon: '',
  //         title: '人群包管理'
  //       },
  //       component: () => import('@/views/audience/package/index'),
  //       redirect: '/audience/package/featured',
  //       children: [
  //         {
  //           name: 'featured',
  //           path: 'featured',
  //           meta: {
  //             icon: '',
  //             title: '精选包管理'
  //           },
  //           hidden: true,
  //           component: () => import('@/views/audience/package/featured/index'),
  //         },
  //         {
  //           name: 'custom',
  //           path: 'custom',
  //           meta: {
  //             icon: '',
  //             title: '人群包管理'
  //           },
  //           hidden: true,
  //           component: () => import('@/views/audience/package/custom/index'),
  //         }
  //       ]
  //     }
  //   ]
  // },
  // {
  //   component: Layout,
  //   meta: {
  //     icon: 'data_list',
  //     title: '用户库'
  //   },
  //   name: '用户库',
  //   path: '/userlibrary',
  //   children: [
  //     {
  //       name: 'crowdpack',
  //       path: 'crowdpack',
  //       meta: {
  //         icon: '',
  //         title: '人群包审核'
  //       },
  //       component: () => import('@/views/userlibrary/crowdpack/index'),
  //     },
  //     {
  //       name: 'packagename',
  //       path: 'packagename',
  //       meta: {
  //         icon: '',
  //         title: '包名标签管理'
  //       },
  //       component: () => import('@/views/userlibrary/packagename/index'),
  //     }
  //   ]
  // },
  // {
  //   component: Layout,
  //   meta: {
  //     icon: 'log',
  //     title: '应用标签管理'
  //   },
  //   name: '应用标签管理',
  //   path: '/app',
  //   children: [
  //     {
  //       component: () => import('@/views/tags/index'),
  //       meta: {
  //         icon: '',
  //         title: '应用标签管理'
  //       },
  //       name: '应用标签管理',
  //       path: 'tags'
  //     }
  //   ]
  // },
  // {
  //   component: Layout,
  //   meta: {
  //     icon: 'system',
  //     title: '云镜中心'
  //   },
  //   name: '云镜中心',
  //   path: '/cloud',
  //   children: [
  //     {
  //       component: () => import('@/views/cloud/customer/index'),
  //       meta: {
  //         icon: '',
  //         title: '客户管理'
  //       },
  //       name: '客户管理',
  //       path: 'customer'
  //     },
  //     {
  //       component: () => import('@/views/cloud/authority'),
  //       meta: {
  //         icon: '',
  //         title: '试用申请'
  //       },
  //       name: '试用申请',
  //       path: 'authority'
  //     }
  //   ]
  // },
  // {
  //   component: Layout,
  //   meta: {
  //     icon: 'system',
  //     title: '权限管理'
  //   },
  //   name: '权限管理',
  //   path: '/authority',
  //   children: [
  //     {
  //       component: () => import('@/views/authority/customer/index'),
  //       meta: {
  //         icon: '',
  //         title: '账号管理'
  //       },
  //       name: '账号管理',
  //       path: 'customer'
  //     },
  //     {
  //       component: () => import('@/views/authority/user/index'),
  //       hidden: true,
  //       meta: {
  //         icon: '',
  //         title: '用户管理'
  //       },
  //       name: '用户管理',
  //       path: 'user'
  //     },
  //     {
  //       component: () => import('@/views/authority/securityconfig'),
  //       meta: {
  //         icon: '',
  //         title: '安全配置'
  //       },
  //       name: '安全配置',
  //       path: 'securityconfig'
  //     },
  //     {
  //       component: () => import('@/views/authority/operationlog'),
  //       meta: {
  //         icon: '',
  //         title: '操作日志'
  //       },
  //       name: '操作日志',
  //       path: 'operationlog'
  //     }


  //   ]
  // }
]
// console.log(store)
// getAu(store.getters.userId ).then(res => {
//   constantRoutes
//   // const accessedRoutes = filterAsyncRouter(res.data)
//   // commit('SET_ROUTES', accessedRoutes)
//   // resolve(accessedRoutes)
// })
export default new Router({
  mode: 'history', // 去掉url中的#
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})
